There was an error while loading. Please reload this page.
1 parent 08d7c75 commit c9dc62dCopy full SHA for c9dc62d
1 file changed
GPU/GPUbenchmark/cuda/Kernels.cu
@@ -91,12 +91,11 @@ __global__ void readChunkMBKernel(
91
chunk_type* results,
92
size_t chunkSize)
93
{
94
+ chunk_type sink{0};
95
for (int i = blockIdx.x * blockDim.x + threadIdx.x; i < chunkSize; i += blockDim.x * gridDim.x) {
- if (chunkPtr[i] == static_cast<chunk_type>(1)) { // actual read operation is performed here
96
- results[chunkId] += chunkPtr[i]; // this case should never happen and waves should be always in sync
97
- printf("Should never happen\n");
98
- }
+ sink += chunkPtr[i];
99
}
+ results[chunkId] = sink;
100
101
102
// Write
0 commit comments